package com.xy.service;

import com.xy.entity.DeviceSimOrders;
import com.xy.mapper.DeviceSimOrdersMapper;
import com.xy.service.DeviceSimOrdersService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import io.swagger.annotations.Api;
import lombok.AllArgsConstructor;

import java.util.List;
import com.xy.utils.R;
import com.xy.utils.PageBean;
import com.xy.dto.DeviceSimOrdersDto;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.PostMapping;
import io.swagger.annotations.ApiOperation;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.xy.utils.MybatisPlusQuery;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.validation.annotation.Validated;
import com.xy.utils.Emptys;

import static com.xy.utils.Beans.copy;
import static com.xy.utils.PlusBeans.toIPage;
import static com.xy.utils.PlusBeans.toPageBean;


/**
* <p>
* 新购SIM卡订单 服务实现类
* </p>
*
* @author 谭斌
* @since 2024-04-03
*/
@Service
@AllArgsConstructor
@Api(tags = "新购SIM卡订单")
public class DeviceSimOrdersServiceImpl extends ServiceImpl<DeviceSimOrdersMapper, DeviceSimOrders> implements DeviceSimOrdersService {

    @PostMapping("obj")
    @ApiOperation("对象查询")
    public R<DeviceSimOrdersDto.Vo> obj(@RequestBody DeviceSimOrdersDto.Vo vo) {
        DeviceSimOrdersDto.SelectList selectList = copy(DeviceSimOrdersDto.SelectList.class, vo);
        List<DeviceSimOrdersDto.Vo> list = list(selectList).getData();
        if(Emptys.check(list)) {
            return R.ok(list.get(0));
        }
        return R.ok();
    }

    @PostMapping("list")
    @ApiOperation("集合查询")
    public R<List<DeviceSimOrdersDto.Vo>> list(@RequestBody DeviceSimOrdersDto.SelectList selectList) {
        LambdaQueryWrapper<DeviceSimOrders> lambdaQueryWrapper = new MybatisPlusQuery().eqWrapper(selectList, DeviceSimOrders.class).build();
        List<DeviceSimOrders> list = list(lambdaQueryWrapper);
        return R.ok(copy(DeviceSimOrdersDto.Vo.class, list));
    }

    @PostMapping("page")
    @ApiOperation("分页查询")
    public R<PageBean<DeviceSimOrdersDto.Vo>> page(@RequestBody DeviceSimOrdersDto.Page page) {
        PageBean pageBean = page.getPage();
        LambdaQueryWrapper<DeviceSimOrders> lambdaQueryWrapper = new MybatisPlusQuery().eqWrapper(page, DeviceSimOrders.class).build();
        IPage<DeviceSimOrders> iPage = page(toIPage(pageBean), lambdaQueryWrapper);
        return R.ok(toPageBean(DeviceSimOrdersDto.Vo.class, iPage));
    }

    @PostMapping("save")
    @ApiOperation("添加")
    public R save(@RequestBody @Validated DeviceSimOrdersDto.Save save) {
        DeviceSimOrders saveInfo = copy(DeviceSimOrders.class, save);
        save(saveInfo);
        return R.ok();
    }

    @PostMapping("update")
    @ApiOperation("修改")
    public R update(@RequestBody @Validated DeviceSimOrdersDto.Update update) {
        DeviceSimOrders updateInfo = copy(DeviceSimOrders.class, update);
        updateById(updateInfo);
        return R.ok();
    }
}